@@ -1,5 +1,5 @@
 /*
- * $Id: cfg.c 5320 2011-07-12 10:42:26Z jakob $
+ * $Id: cfg.c 5432 2011-08-22 12:55:04Z matthijs $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -59,7 +59,8 @@ engine_config(allocator_type* allocator, const char* cfgfile,
     FILE* cfgfd = NULL;
 
     if (!allocator) {
-        ods_log_error("[%s] failed to read: no allocator available", conf_str);
+        ods_log_error("[%s] failed to read: no allocator available",
+            conf_str);
         return NULL;
     }
     ods_log_assert(allocator);
@@ -106,9 +107,9 @@ engine_config(allocator_type* allocator, const char* cfgfile,
         ecfg->chroot = parse_conf_chroot(allocator, cfgfile);
         ecfg->use_syslog = parse_conf_use_syslog(cfgfile);
         ecfg->num_worker_threads = parse_conf_worker_threads(cfgfile);
-        ecfg->num_adapters = 0;
         ecfg->num_signer_threads = parse_conf_signer_threads(cfgfile);
         ecfg->verbosity = cmdline_verbosity;
+        ecfg->num_adapters = 0;
 
         /* done */
         ods_fclose(cfgfd);
