@@ -1,5 +1,5 @@
 /*
- * $Id: worker.c 5320 2011-07-12 10:42:26Z jakob $
+ * $Id: worker.c 5432 2011-08-22 12:55:04Z matthijs $
  *
  * Copyright (c) 2009 NLNet Labs. All rights reserved.
  *
@@ -168,6 +168,14 @@ worker_perform_task(worker_type* worker)
                 worker2str(worker->type), worker->thread_num,
                 task_who2str(task->who));
             status = zone_load_signconf(zone, &what);
+            if (status == ODS_STATUS_UNCHANGED) {
+                if (!zone->signconf->last_modified) {
+                    ods_log_debug("[%s[%i]] no signconf.xml for zone %s yet",
+                        worker2str(worker->type), worker->thread_num,
+                        task_who2str(task->who));
+                }
+                status = ODS_STATUS_ERR;
+            }
 
             /* what to do next */
             when = time_now();
@@ -190,6 +198,7 @@ worker_perform_task(worker_type* worker)
             }
 
             if (status == ODS_STATUS_OK) {
+                zone->prepared = 1;
                 task->interrupt = TASK_NONE;
                 task->halted = TASK_NONE;
             } else {
@@ -206,7 +215,14 @@ worker_perform_task(worker_type* worker)
             ods_log_verbose("[%s[%i]] read zone %s",
                 worker2str(worker->type), worker->thread_num,
                 task_who2str(task->who));
-            status = tools_input(zone);
+            if (!zone->prepared) {
+                ods_log_debug("[%s[%i]] no valid signconf.xml for zone %s yet",
+                    worker2str(worker->type), worker->thread_num,
+                    task_who2str(task->who));
+                status = ODS_STATUS_ERR;
+            } else {
+                status = tools_input(zone);
+            }
 
             /* what to do next */
             what = TASK_NSECIFY;
@@ -270,17 +286,33 @@ worker_perform_task(worker_type* worker)
                 /* queue menial, hard signing work */
                 status = zonedata_queue(zone->zonedata, engine->signq, worker);
                 ods_log_debug("[%s[%i]] wait until drudgers are finished "
-                    " signing zone %s", worker2str(worker->type),
-                    worker->thread_num, task_who2str(task->who));
+                    " signing zone %s, %u signatures queued",
+                    worker2str(worker->type), worker->thread_num,
+                    task_who2str(task->who), worker->jobs_appointed);
 
                 /* sleep until work is done */
-                worker_sleep_unless(worker, 0);
-                if (worker->jobs_failed > 0) {
+                if (!worker->need_to_exit) {
+                    worker_sleep_unless(worker, 0);
+                }
+                if (worker->jobs_failed) {
                     ods_log_error("[%s[%i]] sign zone %s failed: %u of %u "
                         "signatures failed", worker2str(worker->type),
                         worker->thread_num, task_who2str(task->who),
                         worker->jobs_failed, worker->jobs_appointed);
                     status = ODS_STATUS_ERR;
+                } else if (!worker_fulfilled(worker)) {
+                    ods_log_error("[%s[%i]] sign zone %s failed: %u of %u "
+                        "signatures completed", worker2str(worker->type),
+                        worker->thread_num, task_who2str(task->who),
+                        worker->jobs_completed, worker->jobs_appointed);
+                    status = ODS_STATUS_ERR;
+                } else {
+                    ods_log_debug("[%s[%i]] sign zone %s ok: %u of %u "
+                        "signatures succeeded", worker2str(worker->type),
+                        worker->thread_num, task_who2str(task->who),
+                        worker->jobs_completed, worker->jobs_appointed);
+                    ods_log_assert(worker->jobs_appointed ==
+                        worker->jobs_completed);
                 }
                 worker->jobs_appointed = 0;
                 worker->jobs_completed = 0;
@@ -441,7 +473,7 @@ task_perform_fail:
     } else {
         task->backoff = 60;
     }
-    ods_log_error("[%s[%i]] backoff task %s for zone %s with %u seconds",
+    ods_log_info("[%s[%i]] backoff task %s for zone %s with %u seconds",
         worker2str(worker->type), worker->thread_num,
         task_what2str(task->what), task_who2str(task->who), task->backoff);
 
@@ -568,6 +600,9 @@ worker_drudge(worker_type* worker)
     while (worker->need_to_exit == 0) {
         ods_log_debug("[%s[%i]] report for duty", worker2str(worker->type),
             worker->thread_num);
+        chief = NULL;
+        zone = NULL;
+        task = NULL;
 
         lock_basic_lock(&worker->engine->signq->q_lock);
         /* [LOCK] schedule */
@@ -611,13 +646,14 @@ worker_drudge(worker_type* worker)
                 lock_basic_unlock(&chief->worker_lock);
 
                 if (worker_fulfilled(chief) && chief->sleeping) {
+                    ods_log_debug("[%s[%i]] wake up chief[%u], work is done",
+                        worker2str(worker->type), worker->thread_num,
+                        chief->thread_num);
                     worker_wakeup(chief);
+                    chief = NULL;
                 }
             }
             rrset = NULL;
-            zone = NULL;
-            task = NULL;
-            chief = NULL;
         } else {
             ods_log_debug("[%s[%i]] nothing to do", worker2str(worker->type),
                 worker->thread_num);
@@ -625,6 +661,12 @@ worker_drudge(worker_type* worker)
                 &worker->engine->signq->q_threshold);
         }
     }
+    /* wake up chief */
+    if (chief && chief->sleeping) {
+        ods_log_debug("[%s[%i]] wake up chief[%u], i am exiting",
+            worker2str(worker->type), worker->thread_num, chief->thread_num);
+         worker_wakeup(chief);
+    }
 
     /* cleanup open HSM sessions */
     hsm_destroy_context(ctx);
@@ -685,10 +727,15 @@ worker_sleep_unless(worker_type* worker, time_t timeout)
     ods_log_assert(worker);
     lock_basic_lock(&worker->worker_lock);
     /* [LOCK] worker */
-    if (!worker_fulfilled(worker)) {
+    while (!worker->need_to_exit && !worker_fulfilled(worker)) {
         worker->sleeping = 1;
         lock_basic_sleep(&worker->worker_alarm, &worker->worker_lock,
             timeout);
+
+        ods_log_debug("[%s[%i]] somebody poked me, check completed jobs %u "
+           "appointed, %u completed, %u failed", worker2str(worker->type),
+           worker->thread_num, worker->jobs_appointed, worker->jobs_completed,
+           worker->jobs_failed);
     }
     /* [UNLOCK] worker */
     lock_basic_unlock(&worker->worker_lock);
